@@ -1,9 +1,14 @@
 import logging
 import os
+import shutil
+import gzip
+import tempfile
+from time import sleep
+from threading import Thread
 from pathlib import Path
 from os.path import exists
 from threading import RLock
-from datetime import datetime
+from datetime import datetime, timedelta
 from typing import List
 from dataclasses import dataclass
 from pvpower.weather_forecast import WeatherForecast
@@ -67,11 +72,13 @@ class TrainSampleLog:
     def __init__(self, dirname: str):
         self.lock = RLock()
         self.__dirname = dirname
-        #logging.info("using train file " + self.filename)
+        self.__last_compaction_time = datetime.now() - timedelta(days=30)
 
-    @property
-    def filename(self):
-        fn = os.path.join(self.__dirname, "train.csv")
+    def filename(self, compressed: bool = False):
+        if compressed:
+            fn = os.path.join(self.__dirname, "train.csv.gz")
+        else:
+            fn = os.path.join(self.__dirname, "train.csv")
         if not exists(fn):
             directory = Path(fn).parent
             if not exists(directory):
@@ -80,18 +87,30 @@ class TrainSampleLog:
 
     def append(self, sample: LabelledWeatherForecast):
         with self.lock:
-            exits = exists(self.filename)
-            with open(self.filename, "ab") as file:
-                if not exits:
-                    file.write((LabelledWeatherForecast.csv_header() + "\n").encode(encoding='UTF-8'))
+            # plain file
+            fn = self.filename()
+            with open(fn, "ab") as file:
                 line = sample.to_csv() + "\n"
                 file.write(line.encode(encoding='UTF-8'))
 
+            # compressed file
+            compr_fn = self.filename(compressed=True)
+            with gzip.open(compr_fn, "ab") as file:
+                line = sample.to_csv() + "\n"
+                file.write(line.encode(encoding='UTF-8'))
+
+        if datetime.now() > (self.__last_compaction_time + timedelta(days=10)):
+            self.__last_compaction_time = datetime.now()
+            Thread(target=self.compact, args=(15,), daemon=True).start()
+
+
     def all(self) -> List[LabelledWeatherForecast]:
         with self.lock:
-            if exists(self.filename):
+            # plain file
+            fn = self.filename()
+            if exists(fn):
                 try:
-                    with open(self.filename, "rb") as file:
+                    with open(fn, "rb") as file:
                         lines = [raw_line.decode('UTF-8').strip() for raw_line in file.readlines()]
                         samples = []
                         for line in lines:
@@ -101,9 +120,46 @@ class TrainSampleLog:
                                 pass
                         return samples
                 except Exception as e:
-                    logging.warning("error occurred loading " + self.filename + " " + str(e))
+                    logging.warning("error occurred loading " + fn + " " + str(e))
+
+            # compressed file
+            compr_fn = self.filename(compressed=True)
+            if exists(compr_fn):
+                try:
+                    with gzip.open(compr_fn, "rb") as file:
+                        lines = [raw_line.decode('UTF-8').strip() for raw_line in file.readlines()]
+                        samples = []
+                        for line in lines:
+                            try:
+                                samples.append(LabelledWeatherForecast.from_csv(line))
+                            except Exception as e:
+                                pass
+                        return samples
+                except Exception as e:
+                    logging.warning("error occurred loading " + compr_fn + " " + str(e))
         return []
 
+    def compact(self, delay_sec:int = 0):
+        sleep(delay_sec)
+
+        fn = self.filename(compressed=True)
+        samples = self.all()
+        min_datetime = datetime.now() - timedelta(days=400)
+
+        with tempfile.TemporaryDirectory() as tmp_dir:
+            temp_file = os.path.join(tmp_dir, 'trainfile.temp')
+            with gzip.open(temp_file, "wb") as file:
+                file.write((LabelledWeatherForecast.csv_header() + "\n").encode(encoding='UTF-8'))
+                num_samples = len(samples)
+                num_survived = 0
+                for sample in samples:
+                    if sample.time > min_datetime:
+                        num_survived += 1
+                        line = sample.to_csv() + "\n"
+                        file.write(line.encode(encoding='UTF-8'))
+            shutil.move(temp_file, fn)
+            logging.info("train file " + fn + " compacted (" + str(num_samples - num_survived) + " of " + str(num_samples) + " removed)")
+
     def __str__(self):
         return "\n".join([sample.to_csv() for sample in self.all()])
 
